"""Support for Sharp Memory Display framebuffers

For more information about working with Sharp Memory Displays,
see `this Learn guide <https://learn.adafruit.com/adafruit-sharp-memory-display-breakout/circuitpython-displayio-setup>`_.
"""

from __future__ import annotations
